@@ -1,43 +1,49 @@
-// Scripted Forms -- Making GUIs easy for everyone on your team.
-// Copyright (C) 2017 Simon Biggs
-
-// This program is free software: you can redistribute it and/or modify
-// it under the terms of the GNU Affero General Public License as published
-// by the Free Software Foundation, either version 3 of the License, or
-// (at your option) any later version (the "AGPL-3.0+").
-
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Affero General Public License and the additional terms for more
-// details.
-
-// You should have received a copy of the GNU Affero General Public License
-// along with this program. If not, see <http://www.gnu.org/licenses/>.
-
-// ADDITIONAL TERMS are also included as allowed by Section 7 of the GNU
-// Affrero General Public License. These aditional terms are Sections 1, 5,
-// 6, 7, 8, and 9 from the Apache License, Version 2.0 (the "Apache-2.0")
-// where all references to the definition "License" are instead defined to
-// mean the AGPL-3.0+.
-
-// You should have received a copy of the Apache-2.0 along with this
-// program. If not, see <http://www.apache.org/licenses/LICENSE-2.0>.
+/*
+ *  Copyright 2017 Simon Biggs
+ *
+ *  Licensed under the Apache License, Version 2.0 (the "License");
+ *  you may not use this file except in compliance with the License.
+ *  You may obtain a copy of the License at
+ *
+ *         http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ */
 
 import { BoxLayout, Widget } from '@phosphor/widgets';
 import { ServiceManager, ContentsManager } from '@jupyterlab/services';
 import { Toolbar } from '@jupyterlab/apputils';
 
+import { DocumentRegistry } from '@jupyterlab/docregistry';
+import { PathExt } from '@jupyterlab/coreutils';
+
 import { AngularWidget } from './phosphor-angular-loader';
 import { AppComponent } from './app.component';
 import { AppModule } from './app.module';
 
 import { IScriptedForms } from './services/initialisation.service';
 
+/*
+ *  # Create your own Angular JupyterLab extension (cont.)
+ *
+ *  This is part of the guide available at
+ *  <https://github.com/SimonBiggs/scriptedforms/blob/master/scriptedforms/docs/create-your-own-angular-jupyterlab-extension.md>
+ *
+ *  ## Creating the Angular Wrapper Widget
+ *
+ *  This is where the ScriptedForms AngularWrapperWidget is made. Note that the
+ *  Angular Component functions are only ever called within the `run()` function.
+ */
+
 export namespace IScriptedFormsWidget {
   export interface IOptions {
     serviceManager: ServiceManager;
     contentsManager: ContentsManager;
+    context?: DocumentRegistry.Context;
   }
 }
 
@@ -46,6 +52,7 @@ export namespace IAngularWrapperWidget {
     toolbar: Toolbar<Widget>;
     serviceManager: ServiceManager;
     contentsManager: ContentsManager;
+    context?: DocumentRegistry.Context;
   }
 }
 
@@ -86,12 +93,19 @@ export class AngularWrapperWidget extends AngularWidget<
   }
 }
 
-export class ScriptedFormsWidget extends Widget {
+export class ScriptedFormsWidget extends Widget implements DocumentRegistry.IReadyWidget {
+  _context: DocumentRegistry.Context;
   form: AngularWrapperWidget;
+  id: 'ScriptedForms';
 
   constructor(options: IScriptedFormsWidget.IOptions) {
     super();
-    this.addClass('container');
+    if (options.context) {
+      this._context = options.context;
+      this.onPathChanged();
+      this._context.pathChanged.connect(this.onPathChanged, this);
+    }
+    this.addClass('scripted-form-widget');
 
     const layout = (this.layout = new BoxLayout());
     const toolbar = new Toolbar();
@@ -103,9 +117,26 @@ export class ScriptedFormsWidget extends Widget {
     const angularWrapperWidgetOptions = Object.assign({ toolbar }, options);
 
     this.form = new AngularWrapperWidget(angularWrapperWidgetOptions);
-    this.form.addClass('form');
+    this.form.addClass('form-container');
 
     layout.addWidget(this.form);
     BoxLayout.setStretch(this.form, 1);
   }
+
+  get ready() {
+    return Promise.resolve();
+  }
+
+  get context(): DocumentRegistry.Context {
+    return this._context;
+  }
+
+  onPathChanged(): void {
+    this.title.label = PathExt.basename(this._context.path);
+  }
+
+  dispose() {
+    this.form.dispose();
+    super.dispose();
+  }
 }
